@@ -2,7 +2,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-2013 Icinga Developer Team.
+// Copyright (c) 2009-present Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -563,7 +563,11 @@ Ext.ns("Cronk.util.CronkBuilder");
                 var form = this.formPanel.getForm();
                 
                 form.findField('name').setValue(this.cronkCmp.title);
-                form.findField('cid').setValue(Ext.id(null, 'CUSTOM-' + this.cronk.crname));    
+                var cid = this.cronk.crname;
+                if (!cid.match(/^CUSTOM-/)) {
+                    cid = 'CUSTOM-' + this.cronk.crname;
+                }
+                form.findField('cid').setValue(Ext.id(null, cid));    
                 form.findField('module').setValue(this.cronk.params.module);
                 form.findField('action').setValue(this.cronk.params.action);
                 
