@@ -2,7 +2,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-2013 Icinga Developer Team.
+// Copyright (c) 2009-present Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -62,7 +62,7 @@ Icinga.Reporting.util.InputControlBuilder = Ext.extend(Object, {
 
         this.items = new Ext.util.MixedCollection();
 
-        console.log(this.controlStruct);
+        //console.log(this.controlStruct);
     },
 
     /**
@@ -154,4 +154,4 @@ Icinga.Reporting.util.InputControlBuilder = Ext.extend(Object, {
     hasControls: function () {
         return !!(Object.keys(this.controlStruct).length > 0);
     }
-});
\ No newline at end of file
+});
